<?php
/**
 * Inc functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Inc
 */

if ( ! function_exists( 'inc_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function inc_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Inc, use a find and replace
		 * to change 'inc' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'inc', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'inc' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'inc_custom_background_args', array(
			'default-color' => 'f1f1f1',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 100,
			'width'       => 260,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		// Add Support for post-formats
		add_theme_support( 'post-formats', array(
			'quote', 'link'
		) );
	}
endif;
add_action( 'after_setup_theme', 'inc_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function inc_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'inc_content_width', 730 );
}
add_action( 'after_setup_theme', 'inc_content_width', 0 );


add_action('admin_enqueue_scripts', 'inc_media_js', 10);
/**
 * Register scripts for image upload
 *
 * @uses wp_register_script
 * Hooked to admin_print_scripts action hook
 */
function inc_media_js( $hook ) {
    if( $hook != 'widgets.php' )
		return;
	wp_enqueue_style('inc-custom-widgets-style', get_template_directory_uri() . '/css/widgets.css');
	wp_enqueue_script('inc_meta_upload_widget', get_template_directory_uri().'/js/add-image-script-widget.js', array('jquery', 'media-upload', 'thickbox'), false, true);
}

/**
 * Returns a "Continue reading" link for excerpts
 */
function inc_continue_reading() {
	if (!is_admin()) {
		return '&hellip; ';
	}
}
add_filter('excerpt_more', 'inc_continue_reading');

/**
 * Alter the query for the main loop in home page
 *
 * @uses pre_get_posts hook
 */
function inc_alter_home( $query ){
	$inc_settings = inc_get_option_defaults();
	$new_slider_list = array();

	for ($i = 1; $i <= $inc_settings['inc_slider_quantity']; $i++) {
		if (isset($inc_settings['inc_featured_post_slider'][$i]) && $inc_settings['inc_featured_post_slider'][$i] != '' && get_post($inc_settings['inc_featured_post_slider'][$i]) && has_post_thumbnail($inc_settings['inc_featured_post_slider'][$i])) {
			$new_slider_list[$i] = $inc_settings['inc_featured_post_slider'][$i];
		} else {
			$new_slider_list[$i] = '';
		}
	}
	if ( $inc_settings['inc_exclude_slider_post'] != 0 && !empty($new_slider_list) && $inc_settings['inc_disable_slider'] != 1) {
		if( $query->is_main_query() && $query->is_home() ) {
			$query->query_vars['post__not_in'] = $new_slider_list;
		}
	}
}
add_action( 'pre_get_posts','inc_alter_home' );

/**
 * Enqueue scripts and styles.
 */
function inc_scripts() {
	$inc_settings = inc_get_option_defaults();
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/bootstrap/css/bootstrap.min.css', array(), '4.0.0');
	wp_enqueue_style('font-awesome-style', get_template_directory_uri().'/font-awesome/css/font-awesome.css');

	wp_register_style( 'inc-google-fonts', '//fonts.googleapis.com/css?family=Roboto:300,300i,400,400i,700,700i');
	wp_enqueue_style( 'inc-google-fonts' );

	wp_enqueue_style( 'inc-style', get_stylesheet_uri() );

	wp_enqueue_script('inc-scripts', get_template_directory_uri().'/js/scripts.js', array('jquery'), false, true);

	wp_enqueue_script( 'html5', get_template_directory_uri() . '/js/html5.js', array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'inc-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script('bootstrap-script', get_template_directory_uri().'/bootstrap/js/bootstrap.min.js', array(), '4.0.0', true);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_front_page() && $inc_settings['inc_disable_slider'] !== 1 ) {
		wp_enqueue_script('jquery-cycle', get_template_directory_uri().'/js/jquery.cycle.all.js', array('jquery'), '3.0.3', true);
		wp_enqueue_script('inc-slider', get_template_directory_uri().'/js/inc-slider-setting.js', array('jquery-cycle'), false, true);
	}
}
add_action( 'wp_enqueue_scripts', 'inc_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Widgets and Sidebar file
 */
require get_template_directory() . '/inc/inc-widgets.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/functions.php';

/**
 * Load footer info page
 */
require get_template_directory() . '/inc/inc-footer-info.php';

/**
 * Load inc metaboxes
 */
require get_template_directory() . '/inc/inc-metaboxes.php';

